==> 0.0.24-alpha.tar.gz: lib/speedq_printer.dart <==

import 'dart:async';
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:speedq_printer/Device.dart';

class SpeedqPrinter {
    static const MethodChannel _channel = MethodChannel('speedq_printer');

    static Future<String?> get platformVersion async {
        final String? version = await _channel.invokeMethod('getPlatformVersion');
        return version;
    }

    static void init() async {
        await _channel.invokeMethod("init");
    }

    static Future<List<Device>?> getPairedDevices() async {
        List<Device> result = [];
        for(Map<String, dynamic> map in jsonDecode(await _channel.invokeMethod("getPairedDevices")) as List) {
            result.add(Device.fromJson(map));
        }
        return result;
    }

    static void connect(String mac) async {
        await _channel.invokeMethod("connect", {'mac': mac});
    }

    static void print(String text) async {
        await _channel.invokeMethod("print", {'message': text});
    }

    static void printNewLine() async {
        await _channel.invokeListMethod("printNewLine");
    }

    static void printOrder(String message) async{
        _channel.invokeMethod('printOrder', {
            'message': message,
        });
    }

    ///printCustom(String message, int size, int align,{String? charset})
    static void printCenter(String message, int size){
        _channel.invokeMethod('printCenter', {
            'message': message,
            'size': size
        });
    }

    static void printLeft(String message, int size){
        _channel.invokeMethod('printLeft', {
            'message': message,
            'size': size
        });
    }

    static void printRight(String message, int size){
        _channel.invokeMethod('printRight', {
            'message': message,
            'size': size
        });
    }

    static void print3Column(
        String string1, String string2, String string3, int size) =>
        _channel.invokeMethod('print3Column', {
            'string1': string1,
            'string2': string2,
            'string3': string3,
            'size': size,
        });
}

==> 0.1.0-alpha.tar.gz: lib/speedq_printer.dart <==

import 'dart:async';
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:speedq_printer/Device.dart';

class SpeedqPrinter {
    static const MethodChannel _channel = MethodChannel('speedq_printer');

    static Future<String?> get platformVersion async {
        final String? version = await _channel.invokeMethod('getPlatformVersion');
        return version;
    }

    static void init() async {
        await _channel.invokeMethod("init");
    }

    static Future<List<Device>?> getPairedDevices() async {
        List<Device> result = [];
        for(Map<String, dynamic> map in jsonDecode(await _channel.invokeMethod("getPairedDevices")) as List) {
            result.add(Device.fromJson(map));
        }
        return result;
    }

    static void connectBT(String mac) async {
        await _channel.invokeMethod("connectBT", {'mac': mac});
    }

    static void connectUSB() {
        _channel.invokeMethod("connectUSB");
    }

    static void print(String text) async {
        await _channel.invokeMethod("print", {'message': text});
    }

    static void printNewLine() async {
        await _channel.invokeListMethod("printNewLine");
    }

    static void printOrder(String message) async{
        _channel.invokeMethod('printOrder', {
            'message': message,
        });
    }

    ///printCustom(String message, int size, int align,{String? charset})
    static void printCenter(String message, int size){
        _channel.invokeMethod('printCenter', {
            'message': message,
            'size': size
        });
    }

    static void printLeft(String message, int size){
        _channel.invokeMethod('printLeft', {
            'message': message,
            'size': size
        });
    }

    static void printRight(String message, int size){
        _channel.invokeMethod('printRight', {
            'message': message,
            'size': size
        });
    }

    static void print3Column(
        String string1, String string2, String string3, int size) =>
        _channel.invokeMethod('print3Column', {
            'string1': string1,
            'string2': string2,
            'string3': string3,
            'size': size,
        });
}
